'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');
var react$1 = require('@chakra-ui/react');
var UploadStep = require('./UploadStep/UploadStep.js');
var SelectHeaderStep = require('./SelectHeaderStep/SelectHeaderStep.js');
var SelectSheetStep = require('./SelectSheetStep/SelectSheetStep.js');
var mapWorkbook = require('../utils/mapWorkbook.js');
var ValidationStep = require('./ValidationStep/ValidationStep.js');
var MatchColumnsStep = require('./MatchColumnsStep/MatchColumnsStep.js');
var exceedsMaxRecords = require('../utils/exceedsMaxRecords.js');
var useRsi = require('../hooks/useRsi.js');

var Type;
(function (Type) {
    Type[Type["upload"] = 0] = "upload";
    Type[Type["selectSheet"] = 1] = "selectSheet";
    Type[Type["selectHeader"] = 2] = "selectHeader";
    Type[Type["matchColumns"] = 3] = "matchColumns";
    Type[Type["validateData"] = 4] = "validateData";
})(Type || (Type = {}));
const UploadFlow = ({ nextStep }) => {
    const [state, setState] = react.useState({ type: Type.upload });
    const { maxRecords, translations } = useRsi.useRsi();
    const toast = react$1.useToast();
    switch (state.type) {
        case Type.upload:
            return (jsxRuntime.jsx(UploadStep.UploadStep, { onContinue: (workbook) => {
                    if (workbook.SheetNames.length === 1) {
                        if (maxRecords && exceedsMaxRecords.exceedsMaxRecords(workbook.Sheets[workbook.SheetNames[0]], maxRecords)) {
                            return toast({
                                status: "error",
                                variant: "left-accent",
                                position: "bottom-left",
                                title: `${translations.uploadStep.maxRecordsExceeded(maxRecords.toString())}`,
                                isClosable: true,
                            });
                        }
                        setState({ type: Type.selectHeader, data: mapWorkbook.mapWorkbook(workbook) });
                        nextStep();
                    }
                    else {
                        setState({ type: Type.selectSheet, workbook });
                    }
                } }));
        case Type.selectSheet:
            return (jsxRuntime.jsx(SelectSheetStep.SelectSheetStep, { sheetNames: state.workbook.SheetNames, onContinue: (sheetName) => {
                    if (maxRecords && exceedsMaxRecords.exceedsMaxRecords(state.workbook.Sheets[sheetName], maxRecords)) {
                        return toast({
                            status: "error",
                            variant: "left-accent",
                            position: "bottom-left",
                            title: `${translations.uploadStep.maxRecordsExceeded(maxRecords.toString())}`,
                            isClosable: true,
                        });
                    }
                    setState({ type: Type.selectHeader, data: mapWorkbook.mapWorkbook(state.workbook, sheetName) });
                    nextStep();
                } }));
        case Type.selectHeader:
            return (jsxRuntime.jsx(SelectHeaderStep.SelectHeaderStep, { data: state.data, onContinue: (headerValues, data) => {
                    setState({
                        type: Type.matchColumns,
                        headerValues,
                        data,
                    });
                    nextStep();
                } }));
        case Type.matchColumns:
            return (jsxRuntime.jsx(MatchColumnsStep.MatchColumnsStep, { data: state.data, headerValues: state.headerValues, onContinue: (data) => {
                    setState({
                        type: Type.validateData,
                        data,
                    });
                    nextStep();
                } }));
        case Type.validateData:
            return jsxRuntime.jsx(ValidationStep.ValidationStep, { initialData: state.data });
        default:
            return jsxRuntime.jsx(react$1.Progress, { isIndeterminate: true });
    }
};

exports.UploadFlow = UploadFlow;
