import type { DeepPartial } from "ts-essentials";
import type { ChakraStylesConfig } from "chakra-react-select";
import type { SelectOption } from "./types";
export declare const themeOverrides: {
    readonly colors: {
        readonly textColor: "#2D3748";
        readonly subtitleColor: "#718096";
        readonly inactiveColor: "#A0AEC0";
        readonly border: "#E2E8F0";
        readonly background: "white";
        readonly secondaryBackground: "#EDF2F7";
        readonly highlight: "#E2E8F0";
        readonly rsi: {
            readonly 50: "#E6E6FF";
            readonly 100: "#4C63B6";
            readonly 200: "#4C63B6";
            readonly 300: "#8888FC";
            readonly 400: "#7069FA";
            readonly 500: "#5D55FA";
            readonly 600: "#4D3DF7";
            readonly 700: "#3525E6";
            readonly 800: "#2D3A8C";
            readonly 900: "#0C008C";
        };
    };
    readonly shadows: {
        readonly outline: 0;
    };
    readonly components: {
        readonly UploadStep: {
            readonly baseStyle: {
                readonly heading: {
                    readonly fontSize: "3xl";
                    readonly color: "textColor";
                    readonly mb: "2rem";
                };
                readonly title: {
                    readonly fontSize: "2xl";
                    readonly lineHeight: 8;
                    readonly fontWeight: "semibold";
                    readonly color: "textColor";
                };
                readonly subtitle: {
                    readonly fontSize: "md";
                    readonly lineHeight: 6;
                    readonly color: "subtitleColor";
                    readonly mb: "1rem";
                };
                readonly dropzoneText: {
                    readonly size: "lg";
                    readonly lineHeight: 7;
                    readonly fontWeight: "semibold";
                    readonly color: "textColor";
                };
                readonly dropZoneBorder: "rsi.500";
                readonly dropzoneButton: {
                    readonly bg: "rsi.500";
                    readonly mt: "1rem";
                };
            };
        };
        readonly SelectSheetStep: {
            readonly baseStyle: {
                readonly heading: {
                    readonly color: "textColor";
                    readonly mb: 8;
                    readonly fontSize: "3xl";
                };
                readonly radio: {};
                readonly radioLabel: {
                    readonly color: "textColor";
                };
            };
        };
        readonly SelectHeaderStep: {
            readonly baseStyle: {
                readonly heading: {
                    readonly color: "textColor";
                    readonly mb: 8;
                    readonly fontSize: "3xl";
                };
            };
        };
        readonly MatchColumnsStep: {
            readonly baseStyle: {
                readonly heading: {
                    readonly color: "textColor";
                    readonly mb: 8;
                    readonly fontSize: "3xl";
                };
                readonly title: {
                    readonly color: "textColor";
                    readonly fontSize: "2xl";
                    readonly lineHeight: 8;
                    readonly fontWeight: "semibold";
                    readonly mb: 4;
                };
                readonly userTable: {
                    readonly header: {
                        readonly fontSize: "xs";
                        readonly lineHeight: 4;
                        readonly fontWeight: "bold";
                        readonly letterSpacing: "wider";
                        readonly color: "textColor";
                        readonly overflow: "hidden";
                        readonly whiteSpace: "nowrap";
                        readonly textOverflow: "ellipsis";
                        readonly "&[data-ignored]": {
                            readonly color: "inactiveColor";
                        };
                    };
                    readonly cell: {
                        readonly fontSize: "sm";
                        readonly lineHeight: 5;
                        readonly fontWeight: "medium";
                        readonly color: "textColor";
                        readonly px: 6;
                        readonly py: 4;
                        readonly overflow: "hidden";
                        readonly whiteSpace: "nowrap";
                        readonly textOverflow: "ellipsis";
                        readonly "&[data-ignored]": {
                            readonly color: "inactiveColor";
                        };
                    };
                    readonly ignoreButton: {
                        readonly size: "xs";
                        readonly colorScheme: "gray";
                        readonly color: "textColor";
                    };
                };
                readonly selectColumn: {
                    readonly text: {
                        readonly fontSize: "sm";
                        readonly lineHeight: 5;
                        readonly fontWeight: "normal";
                        readonly color: "inactiveColor";
                        readonly px: 4;
                    };
                    readonly accordionLabel: {
                        readonly color: "blue.600";
                        readonly fontSize: "sm";
                        readonly lineHeight: 5;
                        readonly pl: 1;
                    };
                    readonly selectLabel: {
                        readonly pt: "0.375rem";
                        readonly pb: 2;
                        readonly fontSize: "md";
                        readonly lineHeight: 6;
                        readonly fontWeight: "medium";
                        readonly color: "textColor";
                    };
                };
                readonly select: ChakraStylesConfig<SelectOption, false, import("chakra-react-select").GroupBase<SelectOption>>;
            };
        };
        readonly ValidationStep: {
            readonly baseStyle: {
                readonly heading: {
                    readonly color: "textColor";
                    readonly fontSize: "3xl";
                };
                readonly select: ChakraStylesConfig<SelectOption, false, import("chakra-react-select").GroupBase<SelectOption>>;
            };
        };
        readonly MatchIcon: any;
        readonly Steps: {
            parts: ("steps" | "connector" | "description" | "icon" | "label" | "labelContainer" | "step" | "stepContainer" | "stepIconContainer")[];
            baseStyle: import("@chakra-ui/theme-tools").PartsStyleFunction<Pick<import("@chakra-ui/theme-tools").Anatomy<"steps" | "connector" | "description" | "icon" | "label" | "labelContainer" | "step" | "stepContainer" | "stepIconContainer">, "extend" | "selectors" | "classNames" | "keys" | "toPart" | "__type">>;
            sizes: {
                sm: {
                    stepIconContainer: {
                        width: string;
                        height: string;
                        borderWidth: string;
                    };
                    icon: {
                        width: string;
                        height: string;
                    };
                    label: {
                        fontWeight: string;
                        textAlign: string;
                        fontSize: string;
                    };
                    description: {
                        fontWeight: string;
                        textAlign: string;
                        fontSize: string;
                    };
                };
                md: {
                    stepIconContainer: {
                        width: string;
                        height: string;
                        borderWidth: string;
                    };
                    icon: {
                        width: string;
                        height: string;
                    };
                    label: {
                        fontWeight: string;
                        textAlign: string;
                        fontSize: string;
                    };
                    description: {
                        fontWeight: string;
                        textAlign: string;
                        fontSize: string;
                    };
                };
                lg: {
                    stepIconContainer: {
                        width: string;
                        height: string;
                        borderWidth: string;
                    };
                    icon: {
                        width: string;
                        height: string;
                    };
                    label: {
                        fontWeight: string;
                        textAlign: string;
                        fontSize: string;
                    };
                    description: {
                        fontWeight: string;
                        textAlign: string;
                        fontSize: string;
                    };
                };
            };
            defaultProps: {
                size: string;
                colorScheme: string;
            };
        };
        readonly Modal: {
            readonly baseStyle: {
                readonly dialog: {
                    readonly borderRadius: "lg";
                    readonly bg: "background";
                    readonly fontSize: "lg";
                    readonly color: "textColor";
                };
            };
            readonly variants: {
                readonly rsi: {
                    readonly header: {
                        readonly bg: "secondaryBackground";
                        readonly px: "2rem";
                        readonly py: "1.5rem";
                    };
                    readonly body: {
                        readonly bg: "background";
                        readonly display: "flex";
                        readonly paddingX: "2rem";
                        readonly paddingY: "2rem";
                        readonly flexDirection: "column";
                        readonly flex: 1;
                        readonly overflow: "auto";
                        readonly height: "100%";
                    };
                    readonly footer: {
                        readonly bg: "secondaryBackground";
                        readonly py: "1.5rem";
                        readonly justifyContent: "center";
                    };
                    readonly dialog: {
                        readonly outline: "unset";
                        readonly minH: "calc(100vh - 4rem)";
                        readonly maxW: "calc(100vw - 4rem)";
                        readonly my: "2rem";
                        readonly borderRadius: "3xl";
                        readonly overflow: "hidden";
                    };
                };
            };
        };
    };
    readonly styles: {
        readonly global: {
            readonly ".rdg": {
                readonly contain: "size layout style paint";
                readonly borderRadius: "lg";
                readonly border: "none";
                readonly borderTop: "1px solid var(--rdg-border-color)";
                readonly blockSize: "100%";
                readonly "--rdg-row-height": "35px";
                readonly "--rdg-color": "var(--chakra-colors-textColor)";
                readonly "--rdg-background-color": "var(--chakra-colors-background)";
                readonly "--rdg-header-background-color": "var(--chakra-colors-background)";
                readonly "--rdg-row-hover-background-color": "var(--chakra-colors-background)";
                readonly "--rdg-selection-color": "var(--chakra-colors-blue-400)";
                readonly "--rdg-row-selected-background-color": "var(--chakra-colors-rsi-50)";
                readonly "--rdg-error-cell-background-color": "var(--chakra-colors-red-50)";
                readonly "--rdg-warning-cell-background-color": "var(--chakra-colors-orange-50)";
                readonly "--rdg-info-cell-background-color": "var(--chakra-colors-blue-50)";
                readonly "--rdg-border-color": "var(--chakra-colors-border)";
                readonly "--rdg-frozen-cell-box-shadow": "none";
                readonly "--rdg-font-size": "var(--chakra-fontSizes-sm)";
            };
            readonly ".rdg-header-row .rdg-cell": {
                readonly color: "textColor";
                readonly fontSize: "xs";
                readonly lineHeight: 10;
                readonly fontWeight: "bold";
                readonly letterSpacing: "wider";
                readonly textTransform: "uppercase";
                readonly "&:first-of-type": {
                    readonly borderTopLeftRadius: "lg";
                };
                readonly "&:last-child": {
                    readonly borderTopRightRadius: "lg";
                };
            };
            readonly ".rdg-row:last-child .rdg-cell:first-of-type": {
                readonly borderBottomLeftRadius: "lg";
            };
            readonly ".rdg-row:last-child .rdg-cell:last-child": {
                readonly borderBottomRightRadius: "lg";
            };
            readonly ".rdg-cell": {
                readonly contain: "size layout style paint";
                readonly borderRight: "none";
                readonly borderBottom: "1px solid var(--rdg-border-color)";
                readonly whiteSpace: "nowrap";
                readonly overflow: "hidden";
                readonly textOverflow: "ellipsis";
                readonly "&[aria-selected='true']": {
                    readonly boxShadow: "inset 0 0 0 1px var(--rdg-selection-color)";
                };
                readonly "&:first-of-type": {
                    readonly borderLeft: "1px solid var(--rdg-border-color)";
                };
                readonly "&:last-child": {
                    readonly borderRight: "1px solid var(--rdg-border-color)";
                };
            };
            readonly ".rdg-cell-error": {
                readonly backgroundColor: "var(--rdg-error-cell-background-color)";
            };
            readonly ".rdg-cell-warning": {
                readonly backgroundColor: "var(--rdg-warning-cell-background-color)";
            };
            readonly ".rdg-cell-info": {
                readonly backgroundColor: "var(--rdg-info-cell-background-color)";
            };
            readonly ".rdg-static": {
                readonly cursor: "pointer";
            };
            readonly ".rdg-static .rdg-header-row": {
                readonly display: "none";
            };
            readonly ".rdg-static .rdg-cell": {
                readonly "--rdg-selection-color": "none";
            };
            readonly ".rdg-example .rdg-cell": {
                readonly "--rdg-selection-color": "none";
                readonly borderBottom: "none";
            };
            readonly ".rdg-radio": {
                readonly display: "flex";
                readonly alignItems: "center";
            };
            readonly ".rdg-checkbox": {
                readonly "--rdg-selection-color": "none";
                readonly display: "flex";
                readonly alignItems: "center";
            };
        };
    };
};
export declare const colorSchemeOverrides: import("@chakra-ui/react").ThemeExtension<import("@chakra-ui/react").ThemeOverride<{
    components: typeof import("@chakra-ui/theme/dist/declarations/src/components");
    styles: import("@chakra-ui/theme-tools").Styles;
    config: import("@chakra-ui/react").ThemeConfig;
    sizes: {
        container: {
            sm: string;
            md: string;
            lg: string;
            xl: string;
        };
        max: string;
        min: string;
        full: string;
        "3xs": string;
        "2xs": string;
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
        "2xl": string;
        "3xl": string;
        "4xl": string;
        "5xl": string;
        "6xl": string;
        "7xl": string;
        "8xl": string;
        px: string;
        0.5: string;
        1: string;
        1.5: string;
        2: string;
        2.5: string;
        3: string;
        3.5: string;
        4: string;
        5: string;
        6: string;
        7: string;
        8: string;
        9: string;
        10: string;
        12: string;
        14: string;
        16: string;
        20: string;
        24: string;
        28: string;
        32: string;
        36: string;
        40: string;
        44: string;
        48: string;
        52: string;
        56: string;
        60: string;
        64: string;
        72: string;
        80: string;
        96: string;
    };
    shadows: {
        xs: string;
        sm: string;
        base: string;
        md: string;
        lg: string;
        xl: string;
        "2xl": string;
        outline: string;
        inner: string;
        none: string;
        "dark-lg": string;
    };
    space: {
        px: string;
        0.5: string;
        1: string;
        1.5: string;
        2: string;
        2.5: string;
        3: string;
        3.5: string;
        4: string;
        5: string;
        6: string;
        7: string;
        8: string;
        9: string;
        10: string;
        12: string;
        14: string;
        16: string;
        20: string;
        24: string;
        28: string;
        32: string;
        36: string;
        40: string;
        44: string;
        48: string;
        52: string;
        56: string;
        60: string;
        64: string;
        72: string;
        80: string;
        96: string;
    };
    borders: {
        none: number;
        "1px": string;
        "2px": string;
        "4px": string;
        "8px": string;
    };
    transition: {
        property: {
            common: string;
            colors: string;
            dimensions: string;
            position: string;
            background: string;
        };
        easing: {
            "ease-in": string;
            "ease-out": string;
            "ease-in-out": string;
        };
        duration: {
            "ultra-fast": string;
            faster: string;
            fast: string;
            normal: string;
            slow: string;
            slower: string;
            "ultra-slow": string;
        };
    };
    letterSpacings: {
        tighter: string;
        tight: string;
        normal: string;
        wide: string;
        wider: string;
        widest: string;
    };
    lineHeights: {
        normal: string;
        none: number;
        shorter: number;
        short: number;
        base: number;
        tall: number;
        taller: string;
        "3": string;
        "4": string;
        "5": string;
        "6": string;
        "7": string;
        "8": string;
        "9": string;
        "10": string;
    };
    fontWeights: {
        hairline: number;
        thin: number;
        light: number;
        normal: number;
        medium: number;
        semibold: number;
        bold: number;
        extrabold: number;
        black: number;
    };
    fonts: {
        heading: string;
        body: string;
        mono: string;
    };
    fontSizes: {
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
        "2xl": string;
        "3xl": string;
        "4xl": string;
        "5xl": string;
        "6xl": string;
        "7xl": string;
        "8xl": string;
        "9xl": string;
    };
    breakpoints: import("@chakra-ui/theme-tools").Breakpoints<{
        sm: string;
        md: string;
        lg: string;
        xl: string;
        "2xl": string;
    }>;
    zIndices: {
        hide: number;
        auto: string;
        base: number;
        docked: number;
        dropdown: number;
        sticky: number;
        banner: number;
        overlay: number;
        modal: number;
        popover: number;
        skipLink: number;
        toast: number;
        tooltip: number;
    };
    radii: {
        none: string;
        sm: string;
        base: string;
        md: string;
        lg: string;
        xl: string;
        "2xl": string;
        "3xl": string;
        full: string;
    };
    blur: {
        none: number;
        sm: string;
        base: string;
        md: string;
        lg: string;
        xl: string;
        "2xl": string;
        "3xl": string;
    };
    colors: {
        transparent: string;
        current: string;
        black: string;
        white: string;
        whiteAlpha: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        blackAlpha: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        gray: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        red: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        orange: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        yellow: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        green: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        teal: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        blue: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        cyan: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        purple: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        pink: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        linkedin: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        facebook: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        messenger: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        whatsapp: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        twitter: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
        telegram: {
            50: string;
            100: string;
            200: string;
            300: string;
            400: string;
            500: string;
            600: string;
            700: string;
            800: string;
            900: string;
        };
    };
    direction: "ltr";
}>>;
export declare type CustomTheme = DeepPartial<typeof themeOverrides>;
